# FireLaunching

#### 介绍
UDP TCP 协议数据发包工具


#### 安装教程
1. 使用`pip install firelaunching`安装firelaunching库
2. 在cmd终端执行firelaunching即可启动GUI界面
```
> firelaunching
```

3. 或者在Python命令行中

```
> python
>>> import FireLaunching
>>> FireLaunching.main()
```
